@@ -3,7 +3,12 @@
 import click
 
 from multiprocessing import Process
-from ..logger import start_logger, add_puller_to_logger, show_logger_status
+from ..logger import (
+    start_logger,
+    add_puller_to_logger,
+    remove_puller_from_logger,
+    show_logger_status,
+)
 import rpyc
 
 from time import sleep
@@ -28,7 +33,7 @@ def logger(ctx, port):
 @click.option("--port", default=8083, help="Port of the InfluxDB (default 8083)")
 @click.option("--user", default=None, help="Username of the InfluxDB (optional)")
 @click.option("--password", default=None, help="Password of the InfluxDB (optional)")
-@click.option("--database", default="test", help="Name of the database (default test")
+@click.option("--database", help="Name of the database", prompt="Database name: ")
 @click.pass_obj  # pass the logger_port
 def start(logger_port, host, port, user, password, database):
     """Start the logger."""
@@ -50,6 +55,16 @@ def add(logger_port, netloc, measurement, interval):
     add_puller_to_logger(logger_port, netloc, measurement, interval)
 
 
+@logger.command()
+@click.argument("netloc")
+@click.pass_obj
+def remove(logger_port, netloc):
+    """
+    Remove DataService located at NETLOC from the logger.
+    """
+    remove_puller_from_logger(logger_port, netloc)
+
+
 @logger.command()
 @click.pass_obj
 def show(logger_port):
